package com.ruoyi.basetyre.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.basetyre.mapper.BaseTyreMapper;
import com.ruoyi.basetyre.domain.BaseTyre;
import com.ruoyi.basetyre.service.IBaseTyreService;

/**
 * 轮胎基础信息Service业务层处理
 * 
 * @author Yangwl
 * @date 2023-02-06
 */
@Service
public class BaseTyreServiceImpl implements IBaseTyreService 
{
    @Autowired
    private BaseTyreMapper baseTyreMapper;

    /**
     * 查询轮胎基础信息
     * 
     * @param id 轮胎基础信息主键
     * @return 轮胎基础信息
     */
    @Override
    public BaseTyre selectBaseTyreById(String id)
    {
        return baseTyreMapper.selectBaseTyreById(id);
    }

    /**
     * 查询轮胎基础信息列表
     * 
     * @param baseTyre 轮胎基础信息
     * @return 轮胎基础信息
     */
    @Override
    public List<BaseTyre> selectBaseTyreList(BaseTyre baseTyre)
    {
        return baseTyreMapper.selectBaseTyreList(baseTyre);
    }

    /**
     * 新增轮胎基础信息
     * 
     * @param baseTyre 轮胎基础信息
     * @return 结果
     */
    @Override
    public int insertBaseTyre(BaseTyre baseTyre)
    {
        baseTyre.setCreateTime(DateUtils.getNowDate());
        return baseTyreMapper.insertBaseTyre(baseTyre);
    }

    /**
     * 修改轮胎基础信息
     * 
     * @param baseTyre 轮胎基础信息
     * @return 结果
     */
    @Override
    public int updateBaseTyre(BaseTyre baseTyre)
    {
        return baseTyreMapper.updateBaseTyre(baseTyre);
    }

    /**
     * 批量删除轮胎基础信息
     * 
     * @param ids 需要删除的轮胎基础信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseTyreByIds(String[] ids)
    {
        return baseTyreMapper.deleteBaseTyreByIds(ids);
    }

    /**
     * 删除轮胎基础信息信息
     * 
     * @param id 轮胎基础信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseTyreById(String id)
    {
        return baseTyreMapper.deleteBaseTyreById(id);
    }
}
